Class: PokeApiClient::AbilityDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/ability_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AbilityDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/pokeapi_client/models/ability_detail.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::AbilityDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::AbilityDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'is_main_series')
    self.is_main_series = attributes[:'is_main_series']
  end

  if attributes.key?(:'generation')
    self.generation = attributes[:'generation']
  else
    self.generation = nil
  end

  if attributes.key?(:'names')
    if (value = attributes[:'names']).is_a?(Array)
      self.names = value
    end
  else
    self.names = nil
  end

  if attributes.key?(:'effect_entries')
    if (value = attributes[:'effect_entries']).is_a?(Array)
      self.effect_entries = value
    end
  else
    self.effect_entries = nil
  end

  if attributes.key?(:'effect_changes')
    if (value = attributes[:'effect_changes']).is_a?(Array)
      self.effect_changes = value
    end
  else
    self.effect_changes = nil
  end

  if attributes.key?(:'flavor_text_entries')
    if (value = attributes[:'flavor_text_entries']).is_a?(Array)
      self.flavor_text_entries = value
    end
  else
    self.flavor_text_entries = nil
  end

  if attributes.key?(:'pokemon')
    if (value = attributes[:'pokemon']).is_a?(Array)
      self.pokemon = value
    end
  else
    self.pokemon = nil
  end
end

Instance Attribute Details

#effect_changesObject

Returns the value of attribute effect_changes.



30
31
32
# File 'lib/pokeapi_client/models/ability_detail.rb', line 30

def effect_changes
  @effect_changes
end

#effect_entriesObject

Returns the value of attribute effect_entries.



28
29
30
# File 'lib/pokeapi_client/models/ability_detail.rb', line 28

def effect_entries
  @effect_entries
end

#flavor_text_entriesObject

Returns the value of attribute flavor_text_entries.



32
33
34
# File 'lib/pokeapi_client/models/ability_detail.rb', line 32

def flavor_text_entries
  @flavor_text_entries
end

#generationObject

Returns the value of attribute generation.



24
25
26
# File 'lib/pokeapi_client/models/ability_detail.rb', line 24

def generation
  @generation
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/ability_detail.rb', line 18

def id
  @id
end

#is_main_seriesObject

Returns the value of attribute is_main_series.



22
23
24
# File 'lib/pokeapi_client/models/ability_detail.rb', line 22

def is_main_series
  @is_main_series
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pokeapi_client/models/ability_detail.rb', line 20

def name
  @name
end

#namesObject

Returns the value of attribute names.



26
27
28
# File 'lib/pokeapi_client/models/ability_detail.rb', line 26

def names
  @names
end

#pokemonObject

Returns the value of attribute pokemon.



34
35
36
# File 'lib/pokeapi_client/models/ability_detail.rb', line 34

def pokemon
  @pokemon
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/pokeapi_client/models/ability_detail.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/pokeapi_client/models/ability_detail.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/pokeapi_client/models/ability_detail.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'is_main_series' => :'is_main_series',
    :'generation' => :'generation',
    :'names' => :'names',
    :'effect_entries' => :'effect_entries',
    :'effect_changes' => :'effect_changes',
    :'flavor_text_entries' => :'flavor_text_entries',
    :'pokemon' => :'pokemon'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/pokeapi_client/models/ability_detail.rb', line 336

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/pokeapi_client/models/ability_detail.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/pokeapi_client/models/ability_detail.rb', line 62

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'is_main_series' => :'Boolean',
    :'generation' => :'GenerationSummary',
    :'names' => :'Array<AbilityName>',
    :'effect_entries' => :'Array<AbilityEffectText>',
    :'effect_changes' => :'Array<AbilityChange>',
    :'flavor_text_entries' => :'Array<AbilityFlavorText>',
    :'pokemon' => :'Array<AbilityDetailPokemonInner>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



307
308
309
310
311
312
313
314
315
316
317
318
319
# File 'lib/pokeapi_client/models/ability_detail.rb', line 307

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      is_main_series == o.is_main_series &&
      generation == o.generation &&
      names == o.names &&
      effect_entries == o.effect_entries &&
      effect_changes == o.effect_changes &&
      flavor_text_entries == o.flavor_text_entries &&
      pokemon == o.pokemon
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


323
324
325
# File 'lib/pokeapi_client/models/ability_detail.rb', line 323

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



329
330
331
# File 'lib/pokeapi_client/models/ability_detail.rb', line 329

def hash
  [id, name, is_main_series, generation, names, effect_entries, effect_changes, flavor_text_entries, pokemon].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/pokeapi_client/models/ability_detail.rb', line 163

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @generation.nil?
    invalid_properties.push('invalid value for "generation", generation cannot be nil.')
  end

  if @names.nil?
    invalid_properties.push('invalid value for "names", names cannot be nil.')
  end

  if @effect_entries.nil?
    invalid_properties.push('invalid value for "effect_entries", effect_entries cannot be nil.')
  end

  if @effect_changes.nil?
    invalid_properties.push('invalid value for "effect_changes", effect_changes cannot be nil.')
  end

  if @flavor_text_entries.nil?
    invalid_properties.push('invalid value for "flavor_text_entries", flavor_text_entries cannot be nil.')
  end

  if @pokemon.nil?
    invalid_properties.push('invalid value for "pokemon", pokemon cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/pokeapi_client/models/ability_detail.rb', line 358

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/pokeapi_client/models/ability_detail.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @generation.nil?
  return false if @names.nil?
  return false if @effect_entries.nil?
  return false if @effect_changes.nil?
  return false if @flavor_text_entries.nil?
  return false if @pokemon.nil?
  true
end