Class: PokeApiClient::BerriesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pokeapi_client/api/berries_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ BerriesApi

Returns a new instance of BerriesApi.



19
20
21
# File 'lib/pokeapi_client/api/berries_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pokeapi_client/api/berries_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#berry_firmness_list(opts = {}) ⇒ PaginatedBerryFirmnessSummaryList

List berry firmness Berries can be soft or hard. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



29
30
31
32
# File 'lib/pokeapi_client/api/berries_api.rb', line 29

def berry_firmness_list(opts = {})
  data, _status_code, _headers = berry_firmness_list_with_http_info(opts)
  data
end

#berry_firmness_list_with_http_info(opts = {}) ⇒ Array<(PaginatedBerryFirmnessSummaryList, Integer, Hash)>

List berry firmness Berries can be soft or hard. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pokeapi_client/api/berries_api.rb', line 41

def berry_firmness_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BerriesApi.berry_firmness_list ...'
  end
  # resource path
  local_var_path = '/api/v2/berry-firmness/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedBerryFirmnessSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"BerriesApi.berry_firmness_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BerriesApi#berry_firmness_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#berry_firmness_retrieve(id, opts = {}) ⇒ BerryFirmnessDetail

Get berry by firmness Berries can be soft or hard. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



93
94
95
96
# File 'lib/pokeapi_client/api/berries_api.rb', line 93

def berry_firmness_retrieve(id, opts = {})
  data, _status_code, _headers = berry_firmness_retrieve_with_http_info(id, opts)
  data
end

#berry_firmness_retrieve_with_http_info(id, opts = {}) ⇒ Array<(BerryFirmnessDetail, Integer, Hash)>

Get berry by firmness Berries can be soft or hard. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BerryFirmnessDetail, Integer, Hash)>)

    BerryFirmnessDetail data, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/pokeapi_client/api/berries_api.rb', line 103

def berry_firmness_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BerriesApi.berry_firmness_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling BerriesApi.berry_firmness_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/berry-firmness/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BerryFirmnessDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"BerriesApi.berry_firmness_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BerriesApi#berry_firmness_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#berry_flavor_list(opts = {}) ⇒ PaginatedBerryFlavorSummaryList

List berry flavors Flavors determine whether a Pokémon will benefit or suffer from eating a berry based on their nature. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



158
159
160
161
# File 'lib/pokeapi_client/api/berries_api.rb', line 158

def berry_flavor_list(opts = {})
  data, _status_code, _headers = berry_flavor_list_with_http_info(opts)
  data
end

#berry_flavor_list_with_http_info(opts = {}) ⇒ Array<(PaginatedBerryFlavorSummaryList, Integer, Hash)>

List berry flavors Flavors determine whether a Pokémon will benefit or suffer from eating a berry based on their nature. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pokeapi_client/api/berries_api.rb', line 170

def berry_flavor_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BerriesApi.berry_flavor_list ...'
  end
  # resource path
  local_var_path = '/api/v2/berry-flavor/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedBerryFlavorSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"BerriesApi.berry_flavor_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BerriesApi#berry_flavor_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#berry_flavor_retrieve(id, opts = {}) ⇒ BerryFlavorDetail

Get berries by flavor Flavors determine whether a Pokémon will benefit or suffer from eating a berry based on their nature. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



222
223
224
225
# File 'lib/pokeapi_client/api/berries_api.rb', line 222

def berry_flavor_retrieve(id, opts = {})
  data, _status_code, _headers = berry_flavor_retrieve_with_http_info(id, opts)
  data
end

#berry_flavor_retrieve_with_http_info(id, opts = {}) ⇒ Array<(BerryFlavorDetail, Integer, Hash)>

Get berries by flavor Flavors determine whether a Pokémon will benefit or suffer from eating a berry based on their nature. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BerryFlavorDetail, Integer, Hash)>)

    BerryFlavorDetail data, response status code and response headers



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pokeapi_client/api/berries_api.rb', line 232

def berry_flavor_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BerriesApi.berry_flavor_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling BerriesApi.berry_flavor_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/berry-flavor/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BerryFlavorDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"BerriesApi.berry_flavor_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BerriesApi#berry_flavor_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#berry_list(opts = {}) ⇒ PaginatedBerrySummaryList

List berries Berries are small fruits that can provide HP and status condition restoration, stat enhancement, and even damage negation when eaten by Pokémon. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



287
288
289
290
# File 'lib/pokeapi_client/api/berries_api.rb', line 287

def berry_list(opts = {})
  data, _status_code, _headers = berry_list_with_http_info(opts)
  data
end

#berry_list_with_http_info(opts = {}) ⇒ Array<(PaginatedBerrySummaryList, Integer, Hash)>

List berries Berries are small fruits that can provide HP and status condition restoration, stat enhancement, and even damage negation when eaten by Pokémon. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:

  • (Array<(PaginatedBerrySummaryList, Integer, Hash)>)

    PaginatedBerrySummaryList data, response status code and response headers



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/pokeapi_client/api/berries_api.rb', line 299

def berry_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BerriesApi.berry_list ...'
  end
  # resource path
  local_var_path = '/api/v2/berry/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedBerrySummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"BerriesApi.berry_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BerriesApi#berry_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#berry_retrieve(id, opts = {}) ⇒ BerryDetail

Get a berry Berries are small fruits that can provide HP and status condition restoration, stat enhancement, and even damage negation when eaten by Pokémon. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



351
352
353
354
# File 'lib/pokeapi_client/api/berries_api.rb', line 351

def berry_retrieve(id, opts = {})
  data, _status_code, _headers = berry_retrieve_with_http_info(id, opts)
  data
end

#berry_retrieve_with_http_info(id, opts = {}) ⇒ Array<(BerryDetail, Integer, Hash)>

Get a berry Berries are small fruits that can provide HP and status condition restoration, stat enhancement, and even damage negation when eaten by Pokémon. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(BerryDetail, Integer, Hash)>)

    BerryDetail data, response status code and response headers



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/pokeapi_client/api/berries_api.rb', line 361

def berry_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: BerriesApi.berry_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling BerriesApi.berry_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/berry/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'BerryDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"BerriesApi.berry_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: BerriesApi#berry_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end