Class: PokeApiClient::BerryDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/berry_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BerryDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/pokeapi_client/models/berry_detail.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::BerryDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::BerryDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'growth_time')
    self.growth_time = attributes[:'growth_time']
  else
    self.growth_time = nil
  end

  if attributes.key?(:'max_harvest')
    self.max_harvest = attributes[:'max_harvest']
  else
    self.max_harvest = nil
  end

  if attributes.key?(:'natural_gift_power')
    self.natural_gift_power = attributes[:'natural_gift_power']
  else
    self.natural_gift_power = nil
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end

  if attributes.key?(:'smoothness')
    self.smoothness = attributes[:'smoothness']
  else
    self.smoothness = nil
  end

  if attributes.key?(:'soil_dryness')
    self.soil_dryness = attributes[:'soil_dryness']
  else
    self.soil_dryness = nil
  end

  if attributes.key?(:'firmness')
    self.firmness = attributes[:'firmness']
  else
    self.firmness = nil
  end

  if attributes.key?(:'flavors')
    if (value = attributes[:'flavors']).is_a?(Array)
      self.flavors = value
    end
  else
    self.flavors = nil
  end

  if attributes.key?(:'item')
    self.item = attributes[:'item']
  else
    self.item = nil
  end

  if attributes.key?(:'natural_gift_type')
    self.natural_gift_type = attributes[:'natural_gift_type']
  else
    self.natural_gift_type = nil
  end
end

Instance Attribute Details

#firmnessObject

Returns the value of attribute firmness.



34
35
36
# File 'lib/pokeapi_client/models/berry_detail.rb', line 34

def firmness
  @firmness
end

#flavorsObject

Returns the value of attribute flavors.



36
37
38
# File 'lib/pokeapi_client/models/berry_detail.rb', line 36

def flavors
  @flavors
end

#growth_timeObject

Returns the value of attribute growth_time.



22
23
24
# File 'lib/pokeapi_client/models/berry_detail.rb', line 22

def growth_time
  @growth_time
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/berry_detail.rb', line 18

def id
  @id
end

#itemObject

Returns the value of attribute item.



38
39
40
# File 'lib/pokeapi_client/models/berry_detail.rb', line 38

def item
  @item
end

#max_harvestObject

Returns the value of attribute max_harvest.



24
25
26
# File 'lib/pokeapi_client/models/berry_detail.rb', line 24

def max_harvest
  @max_harvest
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pokeapi_client/models/berry_detail.rb', line 20

def name
  @name
end

#natural_gift_powerObject

Returns the value of attribute natural_gift_power.



26
27
28
# File 'lib/pokeapi_client/models/berry_detail.rb', line 26

def natural_gift_power
  @natural_gift_power
end

#natural_gift_typeObject

Returns the value of attribute natural_gift_type.



40
41
42
# File 'lib/pokeapi_client/models/berry_detail.rb', line 40

def natural_gift_type
  @natural_gift_type
end

#sizeObject

Returns the value of attribute size.



28
29
30
# File 'lib/pokeapi_client/models/berry_detail.rb', line 28

def size
  @size
end

#smoothnessObject

Returns the value of attribute smoothness.



30
31
32
# File 'lib/pokeapi_client/models/berry_detail.rb', line 30

def smoothness
  @smoothness
end

#soil_drynessObject

Returns the value of attribute soil_dryness.



32
33
34
# File 'lib/pokeapi_client/models/berry_detail.rb', line 32

def soil_dryness
  @soil_dryness
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/pokeapi_client/models/berry_detail.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/pokeapi_client/models/berry_detail.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/pokeapi_client/models/berry_detail.rb', line 43

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'growth_time' => :'growth_time',
    :'max_harvest' => :'max_harvest',
    :'natural_gift_power' => :'natural_gift_power',
    :'size' => :'size',
    :'smoothness' => :'smoothness',
    :'soil_dryness' => :'soil_dryness',
    :'firmness' => :'firmness',
    :'flavors' => :'flavors',
    :'item' => :'item',
    :'natural_gift_type' => :'natural_gift_type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
# File 'lib/pokeapi_client/models/berry_detail.rb', line 423

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/pokeapi_client/models/berry_detail.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pokeapi_client/models/berry_detail.rb', line 71

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'growth_time' => :'Integer',
    :'max_harvest' => :'Integer',
    :'natural_gift_power' => :'Integer',
    :'size' => :'Integer',
    :'smoothness' => :'Integer',
    :'soil_dryness' => :'Integer',
    :'firmness' => :'BerryFirmnessSummary',
    :'flavors' => :'Array<BerryDetailFlavorsInner>',
    :'item' => :'ItemSummary',
    :'natural_gift_type' => :'TypeSummary'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/pokeapi_client/models/berry_detail.rb', line 391

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      growth_time == o.growth_time &&
      max_harvest == o.max_harvest &&
      natural_gift_power == o.natural_gift_power &&
      size == o.size &&
      smoothness == o.smoothness &&
      soil_dryness == o.soil_dryness &&
      firmness == o.firmness &&
      flavors == o.flavors &&
      item == o.item &&
      natural_gift_type == o.natural_gift_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


410
411
412
# File 'lib/pokeapi_client/models/berry_detail.rb', line 410

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



416
417
418
# File 'lib/pokeapi_client/models/berry_detail.rb', line 416

def hash
  [id, name, growth_time, max_harvest, natural_gift_power, size, smoothness, soil_dryness, firmness, flavors, item, natural_gift_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/pokeapi_client/models/berry_detail.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @growth_time.nil?
    invalid_properties.push('invalid value for "growth_time", growth_time cannot be nil.')
  end

  if @max_harvest.nil?
    invalid_properties.push('invalid value for "max_harvest", max_harvest cannot be nil.')
  end

  if @natural_gift_power.nil?
    invalid_properties.push('invalid value for "natural_gift_power", natural_gift_power cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  if @smoothness.nil?
    invalid_properties.push('invalid value for "smoothness", smoothness cannot be nil.')
  end

  if @soil_dryness.nil?
    invalid_properties.push('invalid value for "soil_dryness", soil_dryness cannot be nil.')
  end

  if @firmness.nil?
    invalid_properties.push('invalid value for "firmness", firmness cannot be nil.')
  end

  if @flavors.nil?
    invalid_properties.push('invalid value for "flavors", flavors cannot be nil.')
  end

  if @item.nil?
    invalid_properties.push('invalid value for "item", item cannot be nil.')
  end

  if @natural_gift_type.nil?
    invalid_properties.push('invalid value for "natural_gift_type", natural_gift_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



445
446
447
448
449
450
451
452
453
454
455
456
457
# File 'lib/pokeapi_client/models/berry_detail.rb', line 445

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/pokeapi_client/models/berry_detail.rb', line 247

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @growth_time.nil?
  return false if @max_harvest.nil?
  return false if @natural_gift_power.nil?
  return false if @size.nil?
  return false if @smoothness.nil?
  return false if @soil_dryness.nil?
  return false if @firmness.nil?
  return false if @flavors.nil?
  return false if @item.nil?
  return false if @natural_gift_type.nil?
  true
end