Class: PokeApiClient::ContestEffectDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/contest_effect_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ContestEffectDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::ContestEffectDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::ContestEffectDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'appeal')
    self.appeal = attributes[:'appeal']
  else
    self.appeal = nil
  end

  if attributes.key?(:'jam')
    self.jam = attributes[:'jam']
  else
    self.jam = nil
  end

  if attributes.key?(:'effect_entries')
    if (value = attributes[:'effect_entries']).is_a?(Array)
      self.effect_entries = value
    end
  else
    self.effect_entries = nil
  end

  if attributes.key?(:'flavor_text_entries')
    if (value = attributes[:'flavor_text_entries']).is_a?(Array)
      self.flavor_text_entries = value
    end
  else
    self.flavor_text_entries = nil
  end
end

Instance Attribute Details

#appealObject

Returns the value of attribute appeal.



20
21
22
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 20

def appeal
  @appeal
end

#effect_entriesObject

Returns the value of attribute effect_entries.



24
25
26
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 24

def effect_entries
  @effect_entries
end

#flavor_text_entriesObject

Returns the value of attribute flavor_text_entries.



26
27
28
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 26

def flavor_text_entries
  @flavor_text_entries
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 18

def id
  @id
end

#jamObject

Returns the value of attribute jam.



22
23
24
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 22

def jam
  @jam
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 29

def self.attribute_map
  {
    :'id' => :'id',
    :'appeal' => :'appeal',
    :'jam' => :'jam',
    :'effect_entries' => :'effect_entries',
    :'flavor_text_entries' => :'flavor_text_entries'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 50

def self.openapi_types
  {
    :'id' => :'Integer',
    :'appeal' => :'Integer',
    :'jam' => :'Integer',
    :'effect_entries' => :'Array<ContestEffectEffectText>',
    :'flavor_text_entries' => :'Array<ContestEffectFlavorText>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      appeal == o.appeal &&
      jam == o.jam &&
      effect_entries == o.effect_entries &&
      flavor_text_entries == o.flavor_text_entries
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 227

def hash
  [id, appeal, jam, effect_entries, flavor_text_entries].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @appeal.nil?
    invalid_properties.push('invalid value for "appeal", appeal cannot be nil.')
  end

  if @jam.nil?
    invalid_properties.push('invalid value for "jam", jam cannot be nil.')
  end

  if @effect_entries.nil?
    invalid_properties.push('invalid value for "effect_entries", effect_entries cannot be nil.')
  end

  if @flavor_text_entries.nil?
    invalid_properties.push('invalid value for "flavor_text_entries", flavor_text_entries cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
# File 'lib/pokeapi_client/models/contest_effect_detail.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @appeal.nil?
  return false if @jam.nil?
  return false if @effect_entries.nil?
  return false if @flavor_text_entries.nil?
  true
end