Class: PokeApiClient::ContestsApi
- Inherits:
-
Object
- Object
- PokeApiClient::ContestsApi
- Defined in:
- lib/pokeapi_client/api/contests_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#contest_effect_list(opts = {}) ⇒ PaginatedContestEffectSummaryList
List contest effects Contest effects refer to the effects of moves when used in contests.
-
#contest_effect_list_with_http_info(opts = {}) ⇒ Array<(PaginatedContestEffectSummaryList, Integer, Hash)>
List contest effects Contest effects refer to the effects of moves when used in contests.
-
#contest_effect_retrieve(id, opts = {}) ⇒ ContestEffectDetail
Get contest effect Contest effects refer to the effects of moves when used in contests.
-
#contest_effect_retrieve_with_http_info(id, opts = {}) ⇒ Array<(ContestEffectDetail, Integer, Hash)>
Get contest effect Contest effects refer to the effects of moves when used in contests.
-
#contest_type_list(opts = {}) ⇒ PaginatedContestTypeSummaryList
List contest types Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests.
-
#contest_type_list_with_http_info(opts = {}) ⇒ Array<(PaginatedContestTypeSummaryList, Integer, Hash)>
List contest types Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests.
-
#contest_type_retrieve(id, opts = {}) ⇒ ContestTypeDetail
Get contest type Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests.
-
#contest_type_retrieve_with_http_info(id, opts = {}) ⇒ Array<(ContestTypeDetail, Integer, Hash)>
Get contest type Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests.
-
#initialize(api_client = ApiClient.default) ⇒ ContestsApi
constructor
A new instance of ContestsApi.
-
#super_contest_effect_list(opts = {}) ⇒ PaginatedSuperContestEffectSummaryList
List super contest effects Super contest effects refer to the effects of moves when used in super contests.
-
#super_contest_effect_list_with_http_info(opts = {}) ⇒ Array<(PaginatedSuperContestEffectSummaryList, Integer, Hash)>
List super contest effects Super contest effects refer to the effects of moves when used in super contests.
-
#super_contest_effect_retrieve(id, opts = {}) ⇒ SuperContestEffectDetail
Get super contest effect Super contest effects refer to the effects of moves when used in super contests.
-
#super_contest_effect_retrieve_with_http_info(id, opts = {}) ⇒ Array<(SuperContestEffectDetail, Integer, Hash)>
Get super contest effect Super contest effects refer to the effects of moves when used in super contests.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContestsApi
Returns a new instance of ContestsApi.
19 20 21 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#contest_effect_list(opts = {}) ⇒ PaginatedContestEffectSummaryList
List contest effects Contest effects refer to the effects of moves when used in contests.
29 30 31 32 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 29 def contest_effect_list(opts = {}) data, _status_code, _headers = contest_effect_list_with_http_info(opts) data end |
#contest_effect_list_with_http_info(opts = {}) ⇒ Array<(PaginatedContestEffectSummaryList, Integer, Hash)>
List contest effects Contest effects refer to the effects of moves when used in contests.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 41 def contest_effect_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContestsApi.contest_effect_list ...' end # resource path local_var_path = '/api/v2/contest-effect/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedContestEffectSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"ContestsApi.contest_effect_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContestsApi#contest_effect_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#contest_effect_retrieve(id, opts = {}) ⇒ ContestEffectDetail
Get contest effect Contest effects refer to the effects of moves when used in contests.
93 94 95 96 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 93 def contest_effect_retrieve(id, opts = {}) data, _status_code, _headers = contest_effect_retrieve_with_http_info(id, opts) data end |
#contest_effect_retrieve_with_http_info(id, opts = {}) ⇒ Array<(ContestEffectDetail, Integer, Hash)>
Get contest effect Contest effects refer to the effects of moves when used in contests.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 103 def contest_effect_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContestsApi.contest_effect_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ContestsApi.contest_effect_retrieve" end # resource path local_var_path = '/api/v2/contest-effect/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ContestEffectDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"ContestsApi.contest_effect_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContestsApi#contest_effect_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#contest_type_list(opts = {}) ⇒ PaginatedContestTypeSummaryList
List contest types Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests. Check out Bulbapedia for greater detail.
158 159 160 161 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 158 def contest_type_list(opts = {}) data, _status_code, _headers = contest_type_list_with_http_info(opts) data end |
#contest_type_list_with_http_info(opts = {}) ⇒ Array<(PaginatedContestTypeSummaryList, Integer, Hash)>
List contest types Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests. Check out Bulbapedia for greater detail.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 170 def contest_type_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContestsApi.contest_type_list ...' end # resource path local_var_path = '/api/v2/contest-type/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedContestTypeSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"ContestsApi.contest_type_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContestsApi#contest_type_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#contest_type_retrieve(id, opts = {}) ⇒ ContestTypeDetail
Get contest type Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests. Check out Bulbapedia for greater detail.
222 223 224 225 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 222 def contest_type_retrieve(id, opts = {}) data, _status_code, _headers = contest_type_retrieve_with_http_info(id, opts) data end |
#contest_type_retrieve_with_http_info(id, opts = {}) ⇒ Array<(ContestTypeDetail, Integer, Hash)>
Get contest type Contest types are categories judges used to weigh a Pokémon's condition in Pokémon contests. Check out Bulbapedia for greater detail.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 232 def contest_type_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContestsApi.contest_type_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ContestsApi.contest_type_retrieve" end # resource path local_var_path = '/api/v2/contest-type/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ContestTypeDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"ContestsApi.contest_type_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContestsApi#contest_type_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#super_contest_effect_list(opts = {}) ⇒ PaginatedSuperContestEffectSummaryList
List super contest effects Super contest effects refer to the effects of moves when used in super contests.
287 288 289 290 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 287 def super_contest_effect_list(opts = {}) data, _status_code, _headers = super_contest_effect_list_with_http_info(opts) data end |
#super_contest_effect_list_with_http_info(opts = {}) ⇒ Array<(PaginatedSuperContestEffectSummaryList, Integer, Hash)>
List super contest effects Super contest effects refer to the effects of moves when used in super contests.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 299 def super_contest_effect_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContestsApi.super_contest_effect_list ...' end # resource path local_var_path = '/api/v2/super-contest-effect/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedSuperContestEffectSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"ContestsApi.super_contest_effect_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContestsApi#super_contest_effect_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#super_contest_effect_retrieve(id, opts = {}) ⇒ SuperContestEffectDetail
Get super contest effect Super contest effects refer to the effects of moves when used in super contests.
351 352 353 354 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 351 def super_contest_effect_retrieve(id, opts = {}) data, _status_code, _headers = super_contest_effect_retrieve_with_http_info(id, opts) data end |
#super_contest_effect_retrieve_with_http_info(id, opts = {}) ⇒ Array<(SuperContestEffectDetail, Integer, Hash)>
Get super contest effect Super contest effects refer to the effects of moves when used in super contests.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/pokeapi_client/api/contests_api.rb', line 361 def super_contest_effect_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContestsApi.super_contest_effect_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ContestsApi.super_contest_effect_retrieve" end # resource path local_var_path = '/api/v2/super-contest-effect/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'SuperContestEffectDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"ContestsApi.super_contest_effect_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContestsApi#super_contest_effect_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |