Class: PokeApiClient::EvolutionApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pokeapi_client/api/evolution_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EvolutionApi

Returns a new instance of EvolutionApi.



19
20
21
# File 'lib/pokeapi_client/api/evolution_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pokeapi_client/api/evolution_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#evolution_chain_list(opts = {}) ⇒ PaginatedEvolutionChainSummaryList

List evolution chains Evolution chains are essentially family trees. They start with the lowest stage within a family and detail evolution conditions for each as well as Pokémon they can evolve into up through the hierarchy.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



29
30
31
32
# File 'lib/pokeapi_client/api/evolution_api.rb', line 29

def evolution_chain_list(opts = {})
  data, _status_code, _headers = evolution_chain_list_with_http_info(opts)
  data
end

#evolution_chain_list_with_http_info(opts = {}) ⇒ Array<(PaginatedEvolutionChainSummaryList, Integer, Hash)>

List evolution chains Evolution chains are essentially family trees. They start with the lowest stage within a family and detail evolution conditions for each as well as Pokémon they can evolve into up through the hierarchy.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pokeapi_client/api/evolution_api.rb', line 41

def evolution_chain_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EvolutionApi.evolution_chain_list ...'
  end
  # resource path
  local_var_path = '/api/v2/evolution-chain/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedEvolutionChainSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"EvolutionApi.evolution_chain_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EvolutionApi#evolution_chain_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#evolution_chain_retrieve(id, opts = {}) ⇒ EvolutionChainDetail

Get evolution chain Evolution chains are essentially family trees. They start with the lowest stage within a family and detail evolution conditions for each as well as Pokémon they can evolve into up through the hierarchy.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



93
94
95
96
# File 'lib/pokeapi_client/api/evolution_api.rb', line 93

def evolution_chain_retrieve(id, opts = {})
  data, _status_code, _headers = evolution_chain_retrieve_with_http_info(id, opts)
  data
end

#evolution_chain_retrieve_with_http_info(id, opts = {}) ⇒ Array<(EvolutionChainDetail, Integer, Hash)>

Get evolution chain Evolution chains are essentially family trees. They start with the lowest stage within a family and detail evolution conditions for each as well as Pokémon they can evolve into up through the hierarchy.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(EvolutionChainDetail, Integer, Hash)>)

    EvolutionChainDetail data, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/pokeapi_client/api/evolution_api.rb', line 103

def evolution_chain_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EvolutionApi.evolution_chain_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling EvolutionApi.evolution_chain_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/evolution-chain/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EvolutionChainDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"EvolutionApi.evolution_chain_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EvolutionApi#evolution_chain_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#evolution_trigger_list(opts = {}) ⇒ PaginatedEvolutionTriggerSummaryList

List evolution triggers Evolution triggers are the events and conditions that cause a Pokémon to evolve. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



158
159
160
161
# File 'lib/pokeapi_client/api/evolution_api.rb', line 158

def evolution_trigger_list(opts = {})
  data, _status_code, _headers = evolution_trigger_list_with_http_info(opts)
  data
end

#evolution_trigger_list_with_http_info(opts = {}) ⇒ Array<(PaginatedEvolutionTriggerSummaryList, Integer, Hash)>

List evolution triggers Evolution triggers are the events and conditions that cause a Pokémon to evolve. Check out Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pokeapi_client/api/evolution_api.rb', line 170

def evolution_trigger_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EvolutionApi.evolution_trigger_list ...'
  end
  # resource path
  local_var_path = '/api/v2/evolution-trigger/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedEvolutionTriggerSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"EvolutionApi.evolution_trigger_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EvolutionApi#evolution_trigger_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#evolution_trigger_retrieve(id, opts = {}) ⇒ EvolutionTriggerDetail

Get evolution trigger Evolution triggers are the events and conditions that cause a Pokémon to evolve. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



222
223
224
225
# File 'lib/pokeapi_client/api/evolution_api.rb', line 222

def evolution_trigger_retrieve(id, opts = {})
  data, _status_code, _headers = evolution_trigger_retrieve_with_http_info(id, opts)
  data
end

#evolution_trigger_retrieve_with_http_info(id, opts = {}) ⇒ Array<(EvolutionTriggerDetail, Integer, Hash)>

Get evolution trigger Evolution triggers are the events and conditions that cause a Pokémon to evolve. Check out Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(EvolutionTriggerDetail, Integer, Hash)>)

    EvolutionTriggerDetail data, response status code and response headers



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pokeapi_client/api/evolution_api.rb', line 232

def evolution_trigger_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EvolutionApi.evolution_trigger_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling EvolutionApi.evolution_trigger_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/evolution-trigger/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'EvolutionTriggerDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"EvolutionApi.evolution_trigger_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EvolutionApi#evolution_trigger_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end