Class: PokeApiClient::GrowthRateDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/growth_rate_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GrowthRateDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::GrowthRateDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::GrowthRateDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'formula')
    self.formula = attributes[:'formula']
  else
    self.formula = nil
  end

  if attributes.key?(:'descriptions')
    if (value = attributes[:'descriptions']).is_a?(Array)
      self.descriptions = value
    end
  else
    self.descriptions = nil
  end

  if attributes.key?(:'levels')
    if (value = attributes[:'levels']).is_a?(Array)
      self.levels = value
    end
  else
    self.levels = nil
  end

  if attributes.key?(:'pokemon_species')
    if (value = attributes[:'pokemon_species']).is_a?(Array)
      self.pokemon_species = value
    end
  else
    self.pokemon_species = nil
  end
end

Instance Attribute Details

#descriptionsObject

Returns the value of attribute descriptions.



24
25
26
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 24

def descriptions
  @descriptions
end

#formulaObject

Returns the value of attribute formula.



22
23
24
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 22

def formula
  @formula
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 18

def id
  @id
end

#levelsObject

Returns the value of attribute levels.



26
27
28
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 26

def levels
  @levels
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 20

def name
  @name
end

#pokemon_speciesObject

Returns the value of attribute pokemon_species.



28
29
30
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 28

def pokemon_species
  @pokemon_species
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
40
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 31

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'formula' => :'formula',
    :'descriptions' => :'descriptions',
    :'levels' => :'levels',
    :'pokemon_species' => :'pokemon_species'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 280

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
62
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 53

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'formula' => :'String',
    :'descriptions' => :'Array<GrowthRateDescription>',
    :'levels' => :'Array<Experience>',
    :'pokemon_species' => :'Array<PokemonSpeciesSummary>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



254
255
256
257
258
259
260
261
262
263
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 254

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      formula == o.formula &&
      descriptions == o.descriptions &&
      levels == o.levels &&
      pokemon_species == o.pokemon_species
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


267
268
269
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 267

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



273
274
275
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 273

def hash
  [id, name, formula, descriptions, levels, pokemon_species].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @formula.nil?
    invalid_properties.push('invalid value for "formula", formula cannot be nil.')
  end

  if @formula.to_s.length > 500
    invalid_properties.push('invalid value for "formula", the character length must be smaller than or equal to 500.')
  end

  if @descriptions.nil?
    invalid_properties.push('invalid value for "descriptions", descriptions cannot be nil.')
  end

  if @levels.nil?
    invalid_properties.push('invalid value for "levels", levels cannot be nil.')
  end

  if @pokemon_species.nil?
    invalid_properties.push('invalid value for "pokemon_species", pokemon_species cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/pokeapi_client/models/growth_rate_detail.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @formula.nil?
  return false if @formula.to_s.length > 500
  return false if @descriptions.nil?
  return false if @levels.nil?
  return false if @pokemon_species.nil?
  true
end