Class: PokeApiClient::LanguageDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PokeApiClient::LanguageDetail
- Defined in:
- lib/pokeapi_client/models/language_detail.rb
Instance Attribute Summary collapse
-
#id ⇒ Object
Returns the value of attribute id.
-
#iso3166 ⇒ Object
Returns the value of attribute iso3166.
-
#iso639 ⇒ Object
Returns the value of attribute iso639.
-
#name ⇒ Object
Returns the value of attribute name.
-
#names ⇒ Object
Returns the value of attribute names.
-
#official ⇒ Object
Returns the value of attribute official.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LanguageDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LanguageDetail
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::LanguageDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::LanguageDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'official') self.official = attributes[:'official'] end if attributes.key?(:'iso639') self.iso639 = attributes[:'iso639'] else self.iso639 = nil end if attributes.key?(:'iso3166') self.iso3166 = attributes[:'iso3166'] else self.iso3166 = nil end if attributes.key?(:'names') if (value = attributes[:'names']).is_a?(Array) self.names = value end else self.names = nil end end |
Instance Attribute Details
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 18 def id @id end |
#iso3166 ⇒ Object
Returns the value of attribute iso3166.
26 27 28 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 26 def iso3166 @iso3166 end |
#iso639 ⇒ Object
Returns the value of attribute iso639.
24 25 26 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 24 def iso639 @iso639 end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 20 def name @name end |
#names ⇒ Object
Returns the value of attribute names.
28 29 30 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 28 def names @names end |
#official ⇒ Object
Returns the value of attribute official.
22 23 24 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 22 def official @official end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 31 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'official' => :'official', :'iso639' => :'iso639', :'iso3166' => :'iso3166', :'names' => :'names' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 53 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'official' => :'Boolean', :'iso639' => :'String', :'iso3166' => :'String', :'names' => :'Array<LanguageName>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
242 243 244 245 246 247 248 249 250 251 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 242 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && official == o.official && iso639 == o.iso639 && iso3166 == o.iso3166 && names == o.names end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 261 def hash [id, name, official, iso639, iso3166, names].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @iso639.nil? invalid_properties.push('invalid value for "iso639", iso639 cannot be nil.') end if @iso639.to_s.length > 10 invalid_properties.push('invalid value for "iso639", the character length must be smaller than or equal to 10.') end if @iso3166.nil? invalid_properties.push('invalid value for "iso3166", iso3166 cannot be nil.') end if @iso3166.to_s.length > 2 invalid_properties.push('invalid value for "iso3166", the character length must be smaller than or equal to 2.') end if @names.nil? invalid_properties.push('invalid value for "names", names cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/pokeapi_client/models/language_detail.rb', line 165 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 100 return false if @iso639.nil? return false if @iso639.to_s.length > 10 return false if @iso3166.nil? return false if @iso3166.to_s.length > 2 return false if @names.nil? true end |