Class: PokeApiClient::MachinesApi
- Inherits:
-
Object
- Object
- PokeApiClient::MachinesApi
- Defined in:
- lib/pokeapi_client/api/machines_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ MachinesApi
constructor
A new instance of MachinesApi.
-
#machine_list(opts = {}) ⇒ PaginatedMachineSummaryList
List machines Machines are the representation of items that teach moves to Pokémon.
-
#machine_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMachineSummaryList, Integer, Hash)>
List machines Machines are the representation of items that teach moves to Pokémon.
-
#machine_retrieve(id, opts = {}) ⇒ MachineDetail
Get machine Machines are the representation of items that teach moves to Pokémon.
-
#machine_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MachineDetail, Integer, Hash)>
Get machine Machines are the representation of items that teach moves to Pokémon.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MachinesApi
Returns a new instance of MachinesApi.
19 20 21 |
# File 'lib/pokeapi_client/api/machines_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pokeapi_client/api/machines_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#machine_list(opts = {}) ⇒ PaginatedMachineSummaryList
List machines Machines are the representation of items that teach moves to Pokémon. They vary from version to version, so it is not certain that one specific TM or HM corresponds to a single Machine.
29 30 31 32 |
# File 'lib/pokeapi_client/api/machines_api.rb', line 29 def machine_list(opts = {}) data, _status_code, _headers = machine_list_with_http_info(opts) data end |
#machine_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMachineSummaryList, Integer, Hash)>
List machines Machines are the representation of items that teach moves to Pokémon. They vary from version to version, so it is not certain that one specific TM or HM corresponds to a single Machine.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pokeapi_client/api/machines_api.rb', line 41 def machine_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MachinesApi.machine_list ...' end # resource path local_var_path = '/api/v2/machine/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedMachineSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"MachinesApi.machine_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MachinesApi#machine_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#machine_retrieve(id, opts = {}) ⇒ MachineDetail
Get machine Machines are the representation of items that teach moves to Pokémon. They vary from version to version, so it is not certain that one specific TM or HM corresponds to a single Machine.
93 94 95 96 |
# File 'lib/pokeapi_client/api/machines_api.rb', line 93 def machine_retrieve(id, opts = {}) data, _status_code, _headers = machine_retrieve_with_http_info(id, opts) data end |
#machine_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MachineDetail, Integer, Hash)>
Get machine Machines are the representation of items that teach moves to Pokémon. They vary from version to version, so it is not certain that one specific TM or HM corresponds to a single Machine.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/pokeapi_client/api/machines_api.rb', line 103 def machine_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MachinesApi.machine_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling MachinesApi.machine_retrieve" end # resource path local_var_path = '/api/v2/machine/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MachineDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"MachinesApi.machine_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: MachinesApi#machine_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |