Class: PokeApiClient::MovesApi

Inherits:
Object
  • Object
show all
Defined in:
lib/pokeapi_client/api/moves_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ MovesApi

Returns a new instance of MovesApi.



19
20
21
# File 'lib/pokeapi_client/api/moves_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/pokeapi_client/api/moves_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#move_ailment_list(opts = {}) ⇒ PaginatedMoveMetaAilmentSummaryList

List move meta ailments Move Ailments are status conditions caused by moves used during battle. See Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



29
30
31
32
# File 'lib/pokeapi_client/api/moves_api.rb', line 29

def move_ailment_list(opts = {})
  data, _status_code, _headers = move_ailment_list_with_http_info(opts)
  data
end

#move_ailment_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMoveMetaAilmentSummaryList, Integer, Hash)>

List move meta ailments Move Ailments are status conditions caused by moves used during battle. See Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/pokeapi_client/api/moves_api.rb', line 41

def move_ailment_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_ailment_list ...'
  end
  # resource path
  local_var_path = '/api/v2/move-ailment/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedMoveMetaAilmentSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_ailment_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_ailment_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_ailment_retrieve(id, opts = {}) ⇒ MoveMetaAilmentDetail

Get move meta ailment Move Ailments are status conditions caused by moves used during battle. See Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



93
94
95
96
# File 'lib/pokeapi_client/api/moves_api.rb', line 93

def move_ailment_retrieve(id, opts = {})
  data, _status_code, _headers = move_ailment_retrieve_with_http_info(id, opts)
  data
end

#move_ailment_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MoveMetaAilmentDetail, Integer, Hash)>

Get move meta ailment Move Ailments are status conditions caused by moves used during battle. See Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MoveMetaAilmentDetail, Integer, Hash)>)

    MoveMetaAilmentDetail data, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/pokeapi_client/api/moves_api.rb', line 103

def move_ailment_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_ailment_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling MovesApi.move_ailment_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/move-ailment/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MoveMetaAilmentDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_ailment_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_ailment_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_battle_style_list(opts = {}) ⇒ PaginatedMoveBattleStyleSummaryList

List move battle styles Styles of moves when used in the Battle Palace. See Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



158
159
160
161
# File 'lib/pokeapi_client/api/moves_api.rb', line 158

def move_battle_style_list(opts = {})
  data, _status_code, _headers = move_battle_style_list_with_http_info(opts)
  data
end

#move_battle_style_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMoveBattleStyleSummaryList, Integer, Hash)>

List move battle styles Styles of moves when used in the Battle Palace. See Bulbapedia for greater detail.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/pokeapi_client/api/moves_api.rb', line 170

def move_battle_style_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_battle_style_list ...'
  end
  # resource path
  local_var_path = '/api/v2/move-battle-style/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedMoveBattleStyleSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_battle_style_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_battle_style_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_battle_style_retrieve(id, opts = {}) ⇒ MoveBattleStyleDetail

Get move battle style Styles of moves when used in the Battle Palace. See Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



222
223
224
225
# File 'lib/pokeapi_client/api/moves_api.rb', line 222

def move_battle_style_retrieve(id, opts = {})
  data, _status_code, _headers = move_battle_style_retrieve_with_http_info(id, opts)
  data
end

#move_battle_style_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MoveBattleStyleDetail, Integer, Hash)>

Get move battle style Styles of moves when used in the Battle Palace. See Bulbapedia for greater detail.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MoveBattleStyleDetail, Integer, Hash)>)

    MoveBattleStyleDetail data, response status code and response headers



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/pokeapi_client/api/moves_api.rb', line 232

def move_battle_style_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_battle_style_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling MovesApi.move_battle_style_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/move-battle-style/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MoveBattleStyleDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_battle_style_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_battle_style_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_category_list(opts = {}) ⇒ PaginatedMoveMetaCategorySummaryList

List move meta categories Very general categories that loosely group move effects.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



287
288
289
290
# File 'lib/pokeapi_client/api/moves_api.rb', line 287

def move_category_list(opts = {})
  data, _status_code, _headers = move_category_list_with_http_info(opts)
  data
end

#move_category_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMoveMetaCategorySummaryList, Integer, Hash)>

List move meta categories Very general categories that loosely group move effects.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/pokeapi_client/api/moves_api.rb', line 299

def move_category_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_category_list ...'
  end
  # resource path
  local_var_path = '/api/v2/move-category/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedMoveMetaCategorySummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_category_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_category_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_category_retrieve(id, opts = {}) ⇒ MoveMetaCategoryDetail

Get move meta category Very general categories that loosely group move effects.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



351
352
353
354
# File 'lib/pokeapi_client/api/moves_api.rb', line 351

def move_category_retrieve(id, opts = {})
  data, _status_code, _headers = move_category_retrieve_with_http_info(id, opts)
  data
end

#move_category_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MoveMetaCategoryDetail, Integer, Hash)>

Get move meta category Very general categories that loosely group move effects.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MoveMetaCategoryDetail, Integer, Hash)>)

    MoveMetaCategoryDetail data, response status code and response headers



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/pokeapi_client/api/moves_api.rb', line 361

def move_category_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_category_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling MovesApi.move_category_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/move-category/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MoveMetaCategoryDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_category_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_category_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_learn_method_list(opts = {}) ⇒ PaginatedMoveLearnMethodSummaryList

List move learn methods Methods by which Pokémon can learn moves.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



416
417
418
419
# File 'lib/pokeapi_client/api/moves_api.rb', line 416

def move_learn_method_list(opts = {})
  data, _status_code, _headers = move_learn_method_list_with_http_info(opts)
  data
end

#move_learn_method_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMoveLearnMethodSummaryList, Integer, Hash)>

List move learn methods Methods by which Pokémon can learn moves.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/pokeapi_client/api/moves_api.rb', line 428

def move_learn_method_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_learn_method_list ...'
  end
  # resource path
  local_var_path = '/api/v2/move-learn-method/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedMoveLearnMethodSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_learn_method_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_learn_method_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_learn_method_retrieve(id, opts = {}) ⇒ MoveLearnMethodDetail

Get move learn method Methods by which Pokémon can learn moves.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



480
481
482
483
# File 'lib/pokeapi_client/api/moves_api.rb', line 480

def move_learn_method_retrieve(id, opts = {})
  data, _status_code, _headers = move_learn_method_retrieve_with_http_info(id, opts)
  data
end

#move_learn_method_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MoveLearnMethodDetail, Integer, Hash)>

Get move learn method Methods by which Pokémon can learn moves.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MoveLearnMethodDetail, Integer, Hash)>)

    MoveLearnMethodDetail data, response status code and response headers



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
# File 'lib/pokeapi_client/api/moves_api.rb', line 490

def move_learn_method_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_learn_method_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling MovesApi.move_learn_method_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/move-learn-method/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MoveLearnMethodDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_learn_method_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_learn_method_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_list(opts = {}) ⇒ PaginatedMoveSummaryList

List moves Moves are the skills of Pokémon in battle. In battle, a Pokémon uses one move each turn. Some moves (including those learned by Hidden Machine) can be used outside of battle as well, usually for the purpose of removing obstacles or exploring new areas.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



545
546
547
548
# File 'lib/pokeapi_client/api/moves_api.rb', line 545

def move_list(opts = {})
  data, _status_code, _headers = move_list_with_http_info(opts)
  data
end

#move_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMoveSummaryList, Integer, Hash)>

List moves Moves are the skills of Pokémon in battle. In battle, a Pokémon uses one move each turn. Some moves (including those learned by Hidden Machine) can be used outside of battle as well, usually for the purpose of removing obstacles or exploring new areas.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:

  • (Array<(PaginatedMoveSummaryList, Integer, Hash)>)

    PaginatedMoveSummaryList data, response status code and response headers



557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
# File 'lib/pokeapi_client/api/moves_api.rb', line 557

def move_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_list ...'
  end
  # resource path
  local_var_path = '/api/v2/move/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedMoveSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_retrieve(id, opts = {}) ⇒ MoveDetail

Get move Moves are the skills of Pokémon in battle. In battle, a Pokémon uses one move each turn. Some moves (including those learned by Hidden Machine) can be used outside of battle as well, usually for the purpose of removing obstacles or exploring new areas.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



609
610
611
612
# File 'lib/pokeapi_client/api/moves_api.rb', line 609

def move_retrieve(id, opts = {})
  data, _status_code, _headers = move_retrieve_with_http_info(id, opts)
  data
end

#move_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MoveDetail, Integer, Hash)>

Get move Moves are the skills of Pokémon in battle. In battle, a Pokémon uses one move each turn. Some moves (including those learned by Hidden Machine) can be used outside of battle as well, usually for the purpose of removing obstacles or exploring new areas.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MoveDetail, Integer, Hash)>)

    MoveDetail data, response status code and response headers



619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'lib/pokeapi_client/api/moves_api.rb', line 619

def move_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling MovesApi.move_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/move/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MoveDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_target_list(opts = {}) ⇒ PaginatedMoveTargetSummaryList

List move targets Targets moves can be directed at during battle. Targets can be Pokémon, environments or even other moves.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



674
675
676
677
# File 'lib/pokeapi_client/api/moves_api.rb', line 674

def move_target_list(opts = {})
  data, _status_code, _headers = move_target_list_with_http_info(opts)
  data
end

#move_target_list_with_http_info(opts = {}) ⇒ Array<(PaginatedMoveTargetSummaryList, Integer, Hash)>

List move targets Targets moves can be directed at during battle. Targets can be Pokémon, environments or even other moves.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    Number of results to return per page.

  • :offset (Integer)

    The initial index from which to return the results.

  • :q (String)

    > Only available locally and not at pokeapi.co Case-insensitive query applied on the `name` property.

Returns:



686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
# File 'lib/pokeapi_client/api/moves_api.rb', line 686

def move_target_list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_target_list ...'
  end
  # resource path
  local_var_path = '/api/v2/move-target/'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'PaginatedMoveTargetSummaryList'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_target_list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_target_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#move_target_retrieve(id, opts = {}) ⇒ MoveTargetDetail

Get move target Targets moves can be directed at during battle. Targets can be Pokémon, environments or even other moves.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



738
739
740
741
# File 'lib/pokeapi_client/api/moves_api.rb', line 738

def move_target_retrieve(id, opts = {})
  data, _status_code, _headers = move_target_retrieve_with_http_info(id, opts)
  data
end

#move_target_retrieve_with_http_info(id, opts = {}) ⇒ Array<(MoveTargetDetail, Integer, Hash)>

Get move target Targets moves can be directed at during battle. Targets can be Pokémon, environments or even other moves.

Parameters:

  • id (String)

    This parameter can be a string or an integer.

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(MoveTargetDetail, Integer, Hash)>)

    MoveTargetDetail data, response status code and response headers



748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
# File 'lib/pokeapi_client/api/moves_api.rb', line 748

def move_target_retrieve_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: MovesApi.move_target_retrieve ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling MovesApi.move_target_retrieve"
  end
  # resource path
  local_var_path = '/api/v2/move-target/{id}/'.sub('{id}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'MoveTargetDetail'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth']

  new_options = opts.merge(
    :operation => :"MovesApi.move_target_retrieve",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: MovesApi#move_target_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end