Class: PokeApiClient::RegionDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/region_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RegionDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/pokeapi_client/models/region_detail.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::RegionDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::RegionDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'locations')
    if (value = attributes[:'locations']).is_a?(Array)
      self.locations = value
    end
  else
    self.locations = nil
  end

  if attributes.key?(:'main_generation')
    self.main_generation = attributes[:'main_generation']
  else
    self.main_generation = nil
  end

  if attributes.key?(:'names')
    if (value = attributes[:'names']).is_a?(Array)
      self.names = value
    end
  else
    self.names = nil
  end

  if attributes.key?(:'pokedexes')
    if (value = attributes[:'pokedexes']).is_a?(Array)
      self.pokedexes = value
    end
  else
    self.pokedexes = nil
  end

  if attributes.key?(:'version_groups')
    if (value = attributes[:'version_groups']).is_a?(Array)
      self.version_groups = value
    end
  else
    self.version_groups = nil
  end
end

Instance Attribute Details

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/region_detail.rb', line 18

def id
  @id
end

#locationsObject

Returns the value of attribute locations.



22
23
24
# File 'lib/pokeapi_client/models/region_detail.rb', line 22

def locations
  @locations
end

#main_generationObject

Returns the value of attribute main_generation.



24
25
26
# File 'lib/pokeapi_client/models/region_detail.rb', line 24

def main_generation
  @main_generation
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pokeapi_client/models/region_detail.rb', line 20

def name
  @name
end

#namesObject

Returns the value of attribute names.



26
27
28
# File 'lib/pokeapi_client/models/region_detail.rb', line 26

def names
  @names
end

#pokedexesObject

Returns the value of attribute pokedexes.



28
29
30
# File 'lib/pokeapi_client/models/region_detail.rb', line 28

def pokedexes
  @pokedexes
end

#version_groupsObject

Returns the value of attribute version_groups.



30
31
32
# File 'lib/pokeapi_client/models/region_detail.rb', line 30

def version_groups
  @version_groups
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/pokeapi_client/models/region_detail.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/pokeapi_client/models/region_detail.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
43
# File 'lib/pokeapi_client/models/region_detail.rb', line 33

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'locations' => :'locations',
    :'main_generation' => :'main_generation',
    :'names' => :'names',
    :'pokedexes' => :'pokedexes',
    :'version_groups' => :'version_groups'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/pokeapi_client/models/region_detail.rb', line 299

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/pokeapi_client/models/region_detail.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
66
# File 'lib/pokeapi_client/models/region_detail.rb', line 56

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'locations' => :'Array<LocationSummary>',
    :'main_generation' => :'GenerationSummary',
    :'names' => :'Array<RegionName>',
    :'pokedexes' => :'Array<PokedexSummary>',
    :'version_groups' => :'Array<AbilityDetailPokemonInnerPokemon>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



272
273
274
275
276
277
278
279
280
281
282
# File 'lib/pokeapi_client/models/region_detail.rb', line 272

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      locations == o.locations &&
      main_generation == o.main_generation &&
      names == o.names &&
      pokedexes == o.pokedexes &&
      version_groups == o.version_groups
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


286
287
288
# File 'lib/pokeapi_client/models/region_detail.rb', line 286

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



292
293
294
# File 'lib/pokeapi_client/models/region_detail.rb', line 292

def hash
  [id, name, locations, main_generation, names, pokedexes, version_groups].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/pokeapi_client/models/region_detail.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @locations.nil?
    invalid_properties.push('invalid value for "locations", locations cannot be nil.')
  end

  if @main_generation.nil?
    invalid_properties.push('invalid value for "main_generation", main_generation cannot be nil.')
  end

  if @names.nil?
    invalid_properties.push('invalid value for "names", names cannot be nil.')
  end

  if @pokedexes.nil?
    invalid_properties.push('invalid value for "pokedexes", pokedexes cannot be nil.')
  end

  if @version_groups.nil?
    invalid_properties.push('invalid value for "version_groups", version_groups cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/pokeapi_client/models/region_detail.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/pokeapi_client/models/region_detail.rb', line 183

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @locations.nil?
  return false if @main_generation.nil?
  return false if @names.nil?
  return false if @pokedexes.nil?
  return false if @version_groups.nil?
  true
end