Class: PokeApiClient::StatDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/stat_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ StatDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/pokeapi_client/models/stat_detail.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::StatDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::StatDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'game_index')
    self.game_index = attributes[:'game_index']
  else
    self.game_index = nil
  end

  if attributes.key?(:'is_battle_only')
    self.is_battle_only = attributes[:'is_battle_only']
  end

  if attributes.key?(:'affecting_moves')
    self.affecting_moves = attributes[:'affecting_moves']
  else
    self.affecting_moves = nil
  end

  if attributes.key?(:'affecting_natures')
    self.affecting_natures = attributes[:'affecting_natures']
  else
    self.affecting_natures = nil
  end

  if attributes.key?(:'characteristics')
    if (value = attributes[:'characteristics']).is_a?(Array)
      self.characteristics = value
    end
  else
    self.characteristics = nil
  end

  if attributes.key?(:'move_damage_class')
    self.move_damage_class = attributes[:'move_damage_class']
  else
    self.move_damage_class = nil
  end

  if attributes.key?(:'names')
    if (value = attributes[:'names']).is_a?(Array)
      self.names = value
    end
  else
    self.names = nil
  end
end

Instance Attribute Details

#affecting_movesObject

Returns the value of attribute affecting_moves.



26
27
28
# File 'lib/pokeapi_client/models/stat_detail.rb', line 26

def affecting_moves
  @affecting_moves
end

#affecting_naturesObject

Returns the value of attribute affecting_natures.



28
29
30
# File 'lib/pokeapi_client/models/stat_detail.rb', line 28

def affecting_natures
  @affecting_natures
end

#characteristicsObject

Returns the value of attribute characteristics.



30
31
32
# File 'lib/pokeapi_client/models/stat_detail.rb', line 30

def characteristics
  @characteristics
end

#game_indexObject

Returns the value of attribute game_index.



22
23
24
# File 'lib/pokeapi_client/models/stat_detail.rb', line 22

def game_index
  @game_index
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/stat_detail.rb', line 18

def id
  @id
end

#is_battle_onlyObject

Returns the value of attribute is_battle_only.



24
25
26
# File 'lib/pokeapi_client/models/stat_detail.rb', line 24

def is_battle_only
  @is_battle_only
end

#move_damage_classObject

Returns the value of attribute move_damage_class.



32
33
34
# File 'lib/pokeapi_client/models/stat_detail.rb', line 32

def move_damage_class
  @move_damage_class
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pokeapi_client/models/stat_detail.rb', line 20

def name
  @name
end

#namesObject

Returns the value of attribute names.



34
35
36
# File 'lib/pokeapi_client/models/stat_detail.rb', line 34

def names
  @names
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/pokeapi_client/models/stat_detail.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/pokeapi_client/models/stat_detail.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/pokeapi_client/models/stat_detail.rb', line 37

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'game_index' => :'game_index',
    :'is_battle_only' => :'is_battle_only',
    :'affecting_moves' => :'affecting_moves',
    :'affecting_natures' => :'affecting_natures',
    :'characteristics' => :'characteristics',
    :'move_damage_class' => :'move_damage_class',
    :'names' => :'names'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/pokeapi_client/models/stat_detail.rb', line 330

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/pokeapi_client/models/stat_detail.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/pokeapi_client/models/stat_detail.rb', line 62

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'game_index' => :'Integer',
    :'is_battle_only' => :'Boolean',
    :'affecting_moves' => :'StatDetailAffectingMoves',
    :'affecting_natures' => :'StatDetailAffectingNatures',
    :'characteristics' => :'Array<CharacteristicSummary>',
    :'move_damage_class' => :'MoveDamageClassSummary',
    :'names' => :'Array<StatName>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/pokeapi_client/models/stat_detail.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      game_index == o.game_index &&
      is_battle_only == o.is_battle_only &&
      affecting_moves == o.affecting_moves &&
      affecting_natures == o.affecting_natures &&
      characteristics == o.characteristics &&
      move_damage_class == o.move_damage_class &&
      names == o.names
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


317
318
319
# File 'lib/pokeapi_client/models/stat_detail.rb', line 317

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



323
324
325
# File 'lib/pokeapi_client/models/stat_detail.rb', line 323

def hash
  [id, name, game_index, is_battle_only, affecting_moves, affecting_natures, characteristics, move_damage_class, names].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/pokeapi_client/models/stat_detail.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @game_index.nil?
    invalid_properties.push('invalid value for "game_index", game_index cannot be nil.')
  end

  if @affecting_moves.nil?
    invalid_properties.push('invalid value for "affecting_moves", affecting_moves cannot be nil.')
  end

  if @affecting_natures.nil?
    invalid_properties.push('invalid value for "affecting_natures", affecting_natures cannot be nil.')
  end

  if @characteristics.nil?
    invalid_properties.push('invalid value for "characteristics", characteristics cannot be nil.')
  end

  if @move_damage_class.nil?
    invalid_properties.push('invalid value for "move_damage_class", move_damage_class cannot be nil.')
  end

  if @names.nil?
    invalid_properties.push('invalid value for "names", names cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/pokeapi_client/models/stat_detail.rb', line 352

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/pokeapi_client/models/stat_detail.rb', line 201

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @game_index.nil?
  return false if @affecting_moves.nil?
  return false if @affecting_natures.nil?
  return false if @characteristics.nil?
  return false if @move_damage_class.nil?
  return false if @names.nil?
  true
end