Class: PokeApiClient::VersionGroupDetail

Inherits:
ApiModelBase show all
Defined in:
lib/pokeapi_client/models/version_group_detail.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VersionGroupDetail

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::VersionGroupDetail` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::VersionGroupDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'order')
    self.order = attributes[:'order']
  end

  if attributes.key?(:'generation')
    self.generation = attributes[:'generation']
  else
    self.generation = nil
  end

  if attributes.key?(:'move_learn_methods')
    if (value = attributes[:'move_learn_methods']).is_a?(Array)
      self.move_learn_methods = value
    end
  else
    self.move_learn_methods = nil
  end

  if attributes.key?(:'pokedexes')
    if (value = attributes[:'pokedexes']).is_a?(Array)
      self.pokedexes = value
    end
  else
    self.pokedexes = nil
  end

  if attributes.key?(:'regions')
    if (value = attributes[:'regions']).is_a?(Array)
      self.regions = value
    end
  else
    self.regions = nil
  end

  if attributes.key?(:'versions')
    if (value = attributes[:'versions']).is_a?(Array)
      self.versions = value
    end
  else
    self.versions = nil
  end
end

Instance Attribute Details

#generationObject

Returns the value of attribute generation.



24
25
26
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 24

def generation
  @generation
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 18

def id
  @id
end

#move_learn_methodsObject

Returns the value of attribute move_learn_methods.



26
27
28
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 26

def move_learn_methods
  @move_learn_methods
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 20

def name
  @name
end

#orderObject

Returns the value of attribute order.



22
23
24
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 22

def order
  @order
end

#pokedexesObject

Returns the value of attribute pokedexes.



28
29
30
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 28

def pokedexes
  @pokedexes
end

#regionsObject

Returns the value of attribute regions.



30
31
32
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 30

def regions
  @regions
end

#versionsObject

Returns the value of attribute versions.



32
33
34
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 32

def versions
  @versions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'order' => :'order',
    :'generation' => :'generation',
    :'move_learn_methods' => :'move_learn_methods',
    :'pokedexes' => :'pokedexes',
    :'regions' => :'regions',
    :'versions' => :'versions'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 309

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
77
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 73

def self.openapi_nullable
  Set.new([
    :'order',
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 59

def self.openapi_types
  {
    :'id' => :'Integer',
    :'name' => :'String',
    :'order' => :'Integer',
    :'generation' => :'GenerationSummary',
    :'move_learn_methods' => :'Array<AbilityDetailPokemonInnerPokemon>',
    :'pokedexes' => :'Array<AbilityDetailPokemonInnerPokemon>',
    :'regions' => :'Array<AbilityDetailPokemonInnerPokemon>',
    :'versions' => :'Array<VersionSummary>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 281

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      order == o.order &&
      generation == o.generation &&
      move_learn_methods == o.move_learn_methods &&
      pokedexes == o.pokedexes &&
      regions == o.regions &&
      versions == o.versions
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


296
297
298
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 296

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



302
303
304
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 302

def hash
  [id, name, order, generation, move_learn_methods, pokedexes, regions, versions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 152

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 100
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.')
  end

  if @generation.nil?
    invalid_properties.push('invalid value for "generation", generation cannot be nil.')
  end

  if @move_learn_methods.nil?
    invalid_properties.push('invalid value for "move_learn_methods", move_learn_methods cannot be nil.')
  end

  if @pokedexes.nil?
    invalid_properties.push('invalid value for "pokedexes", pokedexes cannot be nil.')
  end

  if @regions.nil?
    invalid_properties.push('invalid value for "regions", regions cannot be nil.')
  end

  if @versions.nil?
    invalid_properties.push('invalid value for "versions", versions cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 331

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/pokeapi_client/models/version_group_detail.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 100
  return false if @generation.nil?
  return false if @move_learn_methods.nil?
  return false if @pokedexes.nil?
  return false if @regions.nil?
  return false if @versions.nil?
  true
end