Class: PokeApiClient::GamesApi
- Inherits:
-
Object
- Object
- PokeApiClient::GamesApi
- Defined in:
- lib/pokeapi_client/api/games_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#generation_list(opts = {}) ⇒ PaginatedGenerationSummaryList
List genrations A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include.
-
#generation_list_with_http_info(opts = {}) ⇒ Array<(PaginatedGenerationSummaryList, Integer, Hash)>
List genrations A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include.
-
#generation_retrieve(id, opts = {}) ⇒ GenerationDetail
Get genration A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include.
-
#generation_retrieve_with_http_info(id, opts = {}) ⇒ Array<(GenerationDetail, Integer, Hash)>
Get genration A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include.
-
#initialize(api_client = ApiClient.default) ⇒ GamesApi
constructor
A new instance of GamesApi.
-
#pokedex_list(opts = {}) ⇒ PaginatedPokedexSummaryList
List pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region.
-
#pokedex_list_with_http_info(opts = {}) ⇒ Array<(PaginatedPokedexSummaryList, Integer, Hash)>
List pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region.
-
#pokedex_retrieve(id, opts = {}) ⇒ PokedexDetail
Get pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region.
-
#pokedex_retrieve_with_http_info(id, opts = {}) ⇒ Array<(PokedexDetail, Integer, Hash)>
Get pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region.
-
#version_group_list(opts = {}) ⇒ PaginatedVersionGroupSummaryList
List version groups Version groups categorize highly similar versions of the games.
-
#version_group_list_with_http_info(opts = {}) ⇒ Array<(PaginatedVersionGroupSummaryList, Integer, Hash)>
List version groups Version groups categorize highly similar versions of the games.
-
#version_group_retrieve(id, opts = {}) ⇒ VersionGroupDetail
Get version group Version groups categorize highly similar versions of the games.
-
#version_group_retrieve_with_http_info(id, opts = {}) ⇒ Array<(VersionGroupDetail, Integer, Hash)>
Get version group Version groups categorize highly similar versions of the games.
-
#version_list(opts = {}) ⇒ PaginatedVersionSummaryList
List versions Versions of the games, e.g., Red, Blue or Yellow.
-
#version_list_with_http_info(opts = {}) ⇒ Array<(PaginatedVersionSummaryList, Integer, Hash)>
List versions Versions of the games, e.g., Red, Blue or Yellow.
-
#version_retrieve(id, opts = {}) ⇒ VersionDetail
Get version Versions of the games, e.g., Red, Blue or Yellow.
-
#version_retrieve_with_http_info(id, opts = {}) ⇒ Array<(VersionDetail, Integer, Hash)>
Get version Versions of the games, e.g., Red, Blue or Yellow.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pokeapi_client/api/games_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#generation_list(opts = {}) ⇒ PaginatedGenerationSummaryList
List genrations A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include. In each generation, a new set of Pokémon, Moves, Abilities and Types that did not exist in the previous generation are released.
29 30 31 32 |
# File 'lib/pokeapi_client/api/games_api.rb', line 29 def generation_list(opts = {}) data, _status_code, _headers = generation_list_with_http_info(opts) data end |
#generation_list_with_http_info(opts = {}) ⇒ Array<(PaginatedGenerationSummaryList, Integer, Hash)>
List genrations A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include. In each generation, a new set of Pokémon, Moves, Abilities and Types that did not exist in the previous generation are released.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/pokeapi_client/api/games_api.rb', line 41 def generation_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.generation_list ...' end # resource path local_var_path = '/api/v2/generation/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedGenerationSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.generation_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#generation_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#generation_retrieve(id, opts = {}) ⇒ GenerationDetail
Get genration A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include. In each generation, a new set of Pokémon, Moves, Abilities and Types that did not exist in the previous generation are released.
93 94 95 96 |
# File 'lib/pokeapi_client/api/games_api.rb', line 93 def generation_retrieve(id, opts = {}) data, _status_code, _headers = generation_retrieve_with_http_info(id, opts) data end |
#generation_retrieve_with_http_info(id, opts = {}) ⇒ Array<(GenerationDetail, Integer, Hash)>
Get genration A generation is a grouping of the Pokémon games that separates them based on the Pokémon they include. In each generation, a new set of Pokémon, Moves, Abilities and Types that did not exist in the previous generation are released.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/pokeapi_client/api/games_api.rb', line 103 def generation_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.generation_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GamesApi.generation_retrieve" end # resource path local_var_path = '/api/v2/generation/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'GenerationDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.generation_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#generation_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pokedex_list(opts = {}) ⇒ PaginatedPokedexSummaryList
List pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region. See Bulbapedia for greater detail.
158 159 160 161 |
# File 'lib/pokeapi_client/api/games_api.rb', line 158 def pokedex_list(opts = {}) data, _status_code, _headers = pokedex_list_with_http_info(opts) data end |
#pokedex_list_with_http_info(opts = {}) ⇒ Array<(PaginatedPokedexSummaryList, Integer, Hash)>
List pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region. See Bulbapedia for greater detail.
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/pokeapi_client/api/games_api.rb', line 170 def pokedex_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.pokedex_list ...' end # resource path local_var_path = '/api/v2/pokedex/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedPokedexSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.pokedex_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#pokedex_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pokedex_retrieve(id, opts = {}) ⇒ PokedexDetail
Get pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region. See Bulbapedia for greater detail.
222 223 224 225 |
# File 'lib/pokeapi_client/api/games_api.rb', line 222 def pokedex_retrieve(id, opts = {}) data, _status_code, _headers = pokedex_retrieve_with_http_info(id, opts) data end |
#pokedex_retrieve_with_http_info(id, opts = {}) ⇒ Array<(PokedexDetail, Integer, Hash)>
Get pokedex A Pokédex is a handheld electronic encyclopedia device; one which is capable of recording and retaining information of the various Pokémon in a given region with the exception of the national dex and some smaller dexes related to portions of a region. See Bulbapedia for greater detail.
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/pokeapi_client/api/games_api.rb', line 232 def pokedex_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.pokedex_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GamesApi.pokedex_retrieve" end # resource path local_var_path = '/api/v2/pokedex/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PokedexDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.pokedex_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#pokedex_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#version_group_list(opts = {}) ⇒ PaginatedVersionGroupSummaryList
List version groups Version groups categorize highly similar versions of the games.
287 288 289 290 |
# File 'lib/pokeapi_client/api/games_api.rb', line 287 def version_group_list(opts = {}) data, _status_code, _headers = version_group_list_with_http_info(opts) data end |
#version_group_list_with_http_info(opts = {}) ⇒ Array<(PaginatedVersionGroupSummaryList, Integer, Hash)>
List version groups Version groups categorize highly similar versions of the games.
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 |
# File 'lib/pokeapi_client/api/games_api.rb', line 299 def version_group_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.version_group_list ...' end # resource path local_var_path = '/api/v2/version-group/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedVersionGroupSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.version_group_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#version_group_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#version_group_retrieve(id, opts = {}) ⇒ VersionGroupDetail
Get version group Version groups categorize highly similar versions of the games.
351 352 353 354 |
# File 'lib/pokeapi_client/api/games_api.rb', line 351 def version_group_retrieve(id, opts = {}) data, _status_code, _headers = version_group_retrieve_with_http_info(id, opts) data end |
#version_group_retrieve_with_http_info(id, opts = {}) ⇒ Array<(VersionGroupDetail, Integer, Hash)>
Get version group Version groups categorize highly similar versions of the games.
361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/pokeapi_client/api/games_api.rb', line 361 def version_group_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.version_group_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GamesApi.version_group_retrieve" end # resource path local_var_path = '/api/v2/version-group/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VersionGroupDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.version_group_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#version_group_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#version_list(opts = {}) ⇒ PaginatedVersionSummaryList
List versions Versions of the games, e.g., Red, Blue or Yellow.
416 417 418 419 |
# File 'lib/pokeapi_client/api/games_api.rb', line 416 def version_list(opts = {}) data, _status_code, _headers = version_list_with_http_info(opts) data end |
#version_list_with_http_info(opts = {}) ⇒ Array<(PaginatedVersionSummaryList, Integer, Hash)>
List versions Versions of the games, e.g., Red, Blue or Yellow.
428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 |
# File 'lib/pokeapi_client/api/games_api.rb', line 428 def version_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.version_list ...' end # resource path local_var_path = '/api/v2/version/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedVersionSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.version_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#version_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#version_retrieve(id, opts = {}) ⇒ VersionDetail
Get version Versions of the games, e.g., Red, Blue or Yellow.
480 481 482 483 |
# File 'lib/pokeapi_client/api/games_api.rb', line 480 def version_retrieve(id, opts = {}) data, _status_code, _headers = version_retrieve_with_http_info(id, opts) data end |
#version_retrieve_with_http_info(id, opts = {}) ⇒ Array<(VersionDetail, Integer, Hash)>
Get version Versions of the games, e.g., Red, Blue or Yellow.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/pokeapi_client/api/games_api.rb', line 490 def version_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: GamesApi.version_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling GamesApi.version_retrieve" end # resource path local_var_path = '/api/v2/version/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VersionDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"GamesApi.version_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: GamesApi#version_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |