Class: PokeApiClient::GenerationDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PokeApiClient::GenerationDetail
- Defined in:
- lib/pokeapi_client/models/generation_detail.rb
Instance Attribute Summary collapse
-
#abilities ⇒ Object
Returns the value of attribute abilities.
-
#id ⇒ Object
Returns the value of attribute id.
-
#main_region ⇒ Object
Returns the value of attribute main_region.
-
#moves ⇒ Object
Returns the value of attribute moves.
-
#name ⇒ Object
Returns the value of attribute name.
-
#names ⇒ Object
Returns the value of attribute names.
-
#pokemon_species ⇒ Object
Returns the value of attribute pokemon_species.
-
#types ⇒ Object
Returns the value of attribute types.
-
#version_groups ⇒ Object
Returns the value of attribute version_groups.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GenerationDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GenerationDetail
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::GenerationDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::GenerationDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'abilities') if (value = attributes[:'abilities']).is_a?(Array) self.abilities = value end else self.abilities = nil end if attributes.key?(:'main_region') self.main_region = attributes[:'main_region'] else self.main_region = nil end if attributes.key?(:'moves') if (value = attributes[:'moves']).is_a?(Array) self.moves = value end else self.moves = nil end if attributes.key?(:'names') if (value = attributes[:'names']).is_a?(Array) self.names = value end else self.names = nil end if attributes.key?(:'pokemon_species') if (value = attributes[:'pokemon_species']).is_a?(Array) self.pokemon_species = value end else self.pokemon_species = nil end if attributes.key?(:'types') if (value = attributes[:'types']).is_a?(Array) self.types = value end else self.types = nil end if attributes.key?(:'version_groups') if (value = attributes[:'version_groups']).is_a?(Array) self.version_groups = value end else self.version_groups = nil end end |
Instance Attribute Details
#abilities ⇒ Object
Returns the value of attribute abilities.
22 23 24 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 22 def abilities @abilities end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 18 def id @id end |
#main_region ⇒ Object
Returns the value of attribute main_region.
24 25 26 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 24 def main_region @main_region end |
#moves ⇒ Object
Returns the value of attribute moves.
26 27 28 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 26 def moves @moves end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 20 def name @name end |
#names ⇒ Object
Returns the value of attribute names.
28 29 30 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 28 def names @names end |
#pokemon_species ⇒ Object
Returns the value of attribute pokemon_species.
30 31 32 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 30 def pokemon_species @pokemon_species end |
#types ⇒ Object
Returns the value of attribute types.
32 33 34 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 32 def types @types end |
#version_groups ⇒ Object
Returns the value of attribute version_groups.
34 35 36 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 34 def version_groups @version_groups end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 37 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'abilities' => :'abilities', :'main_region' => :'main_region', :'moves' => :'moves', :'names' => :'names', :'pokemon_species' => :'pokemon_species', :'types' => :'types', :'version_groups' => :'version_groups' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 355 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 62 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'abilities' => :'Array<AbilitySummary>', :'main_region' => :'RegionSummary', :'moves' => :'Array<MoveSummary>', :'names' => :'Array<GenerationName>', :'pokemon_species' => :'Array<PokemonSpeciesSummary>', :'types' => :'Array<TypeSummary>', :'version_groups' => :'Array<VersionGroupSummary>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 326 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && abilities == o.abilities && main_region == o.main_region && moves == o.moves && names == o.names && pokemon_species == o.pokemon_species && types == o.types && version_groups == o.version_groups end |
#eql?(o) ⇒ Boolean
342 343 344 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 342 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
348 349 350 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 348 def hash [id, name, abilities, main_region, moves, names, pokemon_species, types, version_groups].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 167 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @abilities.nil? invalid_properties.push('invalid value for "abilities", abilities cannot be nil.') end if @main_region.nil? invalid_properties.push('invalid value for "main_region", main_region cannot be nil.') end if @moves.nil? invalid_properties.push('invalid value for "moves", moves cannot be nil.') end if @names.nil? invalid_properties.push('invalid value for "names", names cannot be nil.') end if @pokemon_species.nil? invalid_properties.push('invalid value for "pokemon_species", pokemon_species cannot be nil.') end if @types.nil? invalid_properties.push('invalid value for "types", types cannot be nil.') end if @version_groups.nil? invalid_properties.push('invalid value for "version_groups", version_groups cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 377 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/pokeapi_client/models/generation_detail.rb', line 215 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 100 return false if @abilities.nil? return false if @main_region.nil? return false if @moves.nil? return false if @names.nil? return false if @pokemon_species.nil? return false if @types.nil? return false if @version_groups.nil? true end |