Class: PokeApiClient::LocationApi
- Inherits:
-
Object
- Object
- PokeApiClient::LocationApi
- Defined in:
- lib/pokeapi_client/api/location_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#initialize(api_client = ApiClient.default) ⇒ LocationApi
constructor
A new instance of LocationApi.
-
#location_area_list(opts = {}) ⇒ PaginatedLocationAreaSummaryList
List location areas Location areas are sections of areas, such as floors in a building or cave.
-
#location_area_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLocationAreaSummaryList, Integer, Hash)>
List location areas Location areas are sections of areas, such as floors in a building or cave.
-
#location_area_retrieve(id, opts = {}) ⇒ LocationAreaDetail
Get location area Location areas are sections of areas, such as floors in a building or cave.
-
#location_area_retrieve_with_http_info(id, opts = {}) ⇒ Array<(LocationAreaDetail, Integer, Hash)>
Get location area Location areas are sections of areas, such as floors in a building or cave.
-
#location_list(opts = {}) ⇒ PaginatedLocationSummaryList
List locations Locations that can be visited within the games.
-
#location_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLocationSummaryList, Integer, Hash)>
List locations Locations that can be visited within the games.
-
#location_retrieve(id, opts = {}) ⇒ LocationDetail
Get location Locations that can be visited within the games.
-
#location_retrieve_with_http_info(id, opts = {}) ⇒ Array<(LocationDetail, Integer, Hash)>
Get location Locations that can be visited within the games.
-
#pal_park_area_list(opts = {}) ⇒ PaginatedPalParkAreaSummaryList
List pal park areas Areas used for grouping Pokémon encounters in Pal Park.
-
#pal_park_area_list_with_http_info(opts = {}) ⇒ Array<(PaginatedPalParkAreaSummaryList, Integer, Hash)>
List pal park areas Areas used for grouping Pokémon encounters in Pal Park.
-
#pal_park_area_retrieve(id, opts = {}) ⇒ PalParkAreaDetail
Get pal park area Areas used for grouping Pokémon encounters in Pal Park.
-
#pal_park_area_retrieve_with_http_info(id, opts = {}) ⇒ Array<(PalParkAreaDetail, Integer, Hash)>
Get pal park area Areas used for grouping Pokémon encounters in Pal Park.
-
#region_list(opts = {}) ⇒ PaginatedRegionSummaryList
List regions A region is an organized area of the Pokémon world.
-
#region_list_with_http_info(opts = {}) ⇒ Array<(PaginatedRegionSummaryList, Integer, Hash)>
List regions A region is an organized area of the Pokémon world.
-
#region_retrieve(id, opts = {}) ⇒ RegionDetail
Get region A region is an organized area of the Pokémon world.
-
#region_retrieve_with_http_info(id, opts = {}) ⇒ Array<(RegionDetail, Integer, Hash)>
Get region A region is an organized area of the Pokémon world.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ LocationApi
Returns a new instance of LocationApi.
19 20 21 |
# File 'lib/pokeapi_client/api/location_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/pokeapi_client/api/location_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#location_area_list(opts = {}) ⇒ PaginatedLocationAreaSummaryList
List location areas Location areas are sections of areas, such as floors in a building or cave. Each area has its own set of possible Pokémon encounters.
28 29 30 31 |
# File 'lib/pokeapi_client/api/location_api.rb', line 28 def location_area_list(opts = {}) data, _status_code, _headers = location_area_list_with_http_info(opts) data end |
#location_area_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLocationAreaSummaryList, Integer, Hash)>
List location areas Location areas are sections of areas, such as floors in a building or cave. Each area has its own set of possible Pokémon encounters.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/pokeapi_client/api/location_api.rb', line 39 def location_area_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.location_area_list ...' end # resource path local_var_path = '/api/v2/location-area/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedLocationAreaSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.location_area_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#location_area_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#location_area_retrieve(id, opts = {}) ⇒ LocationAreaDetail
Get location area Location areas are sections of areas, such as floors in a building or cave. Each area has its own set of possible Pokémon encounters.
90 91 92 93 |
# File 'lib/pokeapi_client/api/location_api.rb', line 90 def location_area_retrieve(id, opts = {}) data, _status_code, _headers = location_area_retrieve_with_http_info(id, opts) data end |
#location_area_retrieve_with_http_info(id, opts = {}) ⇒ Array<(LocationAreaDetail, Integer, Hash)>
Get location area Location areas are sections of areas, such as floors in a building or cave. Each area has its own set of possible Pokémon encounters.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/pokeapi_client/api/location_api.rb', line 100 def location_area_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.location_area_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LocationApi.location_area_retrieve" end # resource path local_var_path = '/api/v2/location-area/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LocationAreaDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.location_area_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#location_area_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#location_list(opts = {}) ⇒ PaginatedLocationSummaryList
List locations Locations that can be visited within the games. Locations make up sizable portions of regions, like cities or routes.
155 156 157 158 |
# File 'lib/pokeapi_client/api/location_api.rb', line 155 def location_list(opts = {}) data, _status_code, _headers = location_list_with_http_info(opts) data end |
#location_list_with_http_info(opts = {}) ⇒ Array<(PaginatedLocationSummaryList, Integer, Hash)>
List locations Locations that can be visited within the games. Locations make up sizable portions of regions, like cities or routes.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/pokeapi_client/api/location_api.rb', line 167 def location_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.location_list ...' end # resource path local_var_path = '/api/v2/location/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedLocationSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.location_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#location_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#location_retrieve(id, opts = {}) ⇒ LocationDetail
Get location Locations that can be visited within the games. Locations make up sizable portions of regions, like cities or routes.
219 220 221 222 |
# File 'lib/pokeapi_client/api/location_api.rb', line 219 def location_retrieve(id, opts = {}) data, _status_code, _headers = location_retrieve_with_http_info(id, opts) data end |
#location_retrieve_with_http_info(id, opts = {}) ⇒ Array<(LocationDetail, Integer, Hash)>
Get location Locations that can be visited within the games. Locations make up sizable portions of regions, like cities or routes.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/pokeapi_client/api/location_api.rb', line 229 def location_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.location_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LocationApi.location_retrieve" end # resource path local_var_path = '/api/v2/location/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'LocationDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.location_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#location_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pal_park_area_list(opts = {}) ⇒ PaginatedPalParkAreaSummaryList
List pal park areas Areas used for grouping Pokémon encounters in Pal Park. They're like habitats that are specific to Pal Park.
284 285 286 287 |
# File 'lib/pokeapi_client/api/location_api.rb', line 284 def pal_park_area_list(opts = {}) data, _status_code, _headers = pal_park_area_list_with_http_info(opts) data end |
#pal_park_area_list_with_http_info(opts = {}) ⇒ Array<(PaginatedPalParkAreaSummaryList, Integer, Hash)>
List pal park areas Areas used for grouping Pokémon encounters in Pal Park. They're like habitats that are specific to Pal Park.
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 |
# File 'lib/pokeapi_client/api/location_api.rb', line 296 def pal_park_area_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.pal_park_area_list ...' end # resource path local_var_path = '/api/v2/pal-park-area/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedPalParkAreaSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.pal_park_area_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#pal_park_area_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#pal_park_area_retrieve(id, opts = {}) ⇒ PalParkAreaDetail
Get pal park area Areas used for grouping Pokémon encounters in Pal Park. They're like habitats that are specific to Pal Park.
348 349 350 351 |
# File 'lib/pokeapi_client/api/location_api.rb', line 348 def pal_park_area_retrieve(id, opts = {}) data, _status_code, _headers = pal_park_area_retrieve_with_http_info(id, opts) data end |
#pal_park_area_retrieve_with_http_info(id, opts = {}) ⇒ Array<(PalParkAreaDetail, Integer, Hash)>
Get pal park area Areas used for grouping Pokémon encounters in Pal Park. They're like habitats that are specific to Pal Park.
358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/pokeapi_client/api/location_api.rb', line 358 def pal_park_area_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.pal_park_area_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LocationApi.pal_park_area_retrieve" end # resource path local_var_path = '/api/v2/pal-park-area/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PalParkAreaDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.pal_park_area_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#pal_park_area_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#region_list(opts = {}) ⇒ PaginatedRegionSummaryList
List regions A region is an organized area of the Pokémon world. Most often, the main difference between regions is the species of Pokémon that can be encountered within them.
413 414 415 416 |
# File 'lib/pokeapi_client/api/location_api.rb', line 413 def region_list(opts = {}) data, _status_code, _headers = region_list_with_http_info(opts) data end |
#region_list_with_http_info(opts = {}) ⇒ Array<(PaginatedRegionSummaryList, Integer, Hash)>
List regions A region is an organized area of the Pokémon world. Most often, the main difference between regions is the species of Pokémon that can be encountered within them.
425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 |
# File 'lib/pokeapi_client/api/location_api.rb', line 425 def region_list_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.region_list ...' end # resource path local_var_path = '/api/v2/region/' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PaginatedRegionSummaryList' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.region_list", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#region_list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#region_retrieve(id, opts = {}) ⇒ RegionDetail
Get region A region is an organized area of the Pokémon world. Most often, the main difference between regions is the species of Pokémon that can be encountered within them.
477 478 479 480 |
# File 'lib/pokeapi_client/api/location_api.rb', line 477 def region_retrieve(id, opts = {}) data, _status_code, _headers = region_retrieve_with_http_info(id, opts) data end |
#region_retrieve_with_http_info(id, opts = {}) ⇒ Array<(RegionDetail, Integer, Hash)>
Get region A region is an organized area of the Pokémon world. Most often, the main difference between regions is the species of Pokémon that can be encountered within them.
487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 |
# File 'lib/pokeapi_client/api/location_api.rb', line 487 def region_retrieve_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: LocationApi.region_retrieve ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling LocationApi.region_retrieve" end # resource path local_var_path = '/api/v2/region/{id}/'.sub('{id}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RegionDetail' # auth_names auth_names = opts[:debug_auth_names] || ['basicAuth', 'cookieAuth'] = opts.merge( :operation => :"LocationApi.region_retrieve", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: LocationApi#region_retrieve\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |