Class: PokeApiClient::NatureDetail
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- PokeApiClient::NatureDetail
- Defined in:
- lib/pokeapi_client/models/nature_detail.rb
Instance Attribute Summary collapse
-
#berries ⇒ Object
Returns the value of attribute berries.
-
#decreased_stat ⇒ Object
Returns the value of attribute decreased_stat.
-
#hates_flavor ⇒ Object
Returns the value of attribute hates_flavor.
-
#id ⇒ Object
Returns the value of attribute id.
-
#increased_stat ⇒ Object
Returns the value of attribute increased_stat.
-
#likes_flavor ⇒ Object
Returns the value of attribute likes_flavor.
-
#move_battle_style_preferences ⇒ Object
Returns the value of attribute move_battle_style_preferences.
-
#name ⇒ Object
Returns the value of attribute name.
-
#names ⇒ Object
Returns the value of attribute names.
-
#pokeathlon_stat_changes ⇒ Object
Returns the value of attribute pokeathlon_stat_changes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ NatureDetail
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ NatureDetail
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `PokeApiClient::NatureDetail` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `PokeApiClient::NatureDetail`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'decreased_stat') self.decreased_stat = attributes[:'decreased_stat'] else self.decreased_stat = nil end if attributes.key?(:'increased_stat') self.increased_stat = attributes[:'increased_stat'] else self.increased_stat = nil end if attributes.key?(:'likes_flavor') self.likes_flavor = attributes[:'likes_flavor'] else self.likes_flavor = nil end if attributes.key?(:'hates_flavor') self.hates_flavor = attributes[:'hates_flavor'] else self.hates_flavor = nil end if attributes.key?(:'berries') if (value = attributes[:'berries']).is_a?(Array) self.berries = value end else self.berries = nil end if attributes.key?(:'pokeathlon_stat_changes') if (value = attributes[:'pokeathlon_stat_changes']).is_a?(Array) self.pokeathlon_stat_changes = value end else self.pokeathlon_stat_changes = nil end if attributes.key?(:'move_battle_style_preferences') if (value = attributes[:'move_battle_style_preferences']).is_a?(Array) self.move_battle_style_preferences = value end else self.move_battle_style_preferences = nil end if attributes.key?(:'names') if (value = attributes[:'names']).is_a?(Array) self.names = value end else self.names = nil end end |
Instance Attribute Details
#berries ⇒ Object
Returns the value of attribute berries.
30 31 32 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 30 def berries @berries end |
#decreased_stat ⇒ Object
Returns the value of attribute decreased_stat.
22 23 24 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 22 def decreased_stat @decreased_stat end |
#hates_flavor ⇒ Object
Returns the value of attribute hates_flavor.
28 29 30 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 28 def hates_flavor @hates_flavor end |
#id ⇒ Object
Returns the value of attribute id.
18 19 20 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 18 def id @id end |
#increased_stat ⇒ Object
Returns the value of attribute increased_stat.
24 25 26 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 24 def increased_stat @increased_stat end |
#likes_flavor ⇒ Object
Returns the value of attribute likes_flavor.
26 27 28 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 26 def likes_flavor @likes_flavor end |
#move_battle_style_preferences ⇒ Object
Returns the value of attribute move_battle_style_preferences.
34 35 36 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 34 def move_battle_style_preferences @move_battle_style_preferences end |
#name ⇒ Object
Returns the value of attribute name.
20 21 22 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 20 def name @name end |
#names ⇒ Object
Returns the value of attribute names.
36 37 38 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 36 def names @names end |
#pokeathlon_stat_changes ⇒ Object
Returns the value of attribute pokeathlon_stat_changes.
32 33 34 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 32 def pokeathlon_stat_changes @pokeathlon_stat_changes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 39 def self.attribute_map { :'id' => :'id', :'name' => :'name', :'decreased_stat' => :'decreased_stat', :'increased_stat' => :'increased_stat', :'likes_flavor' => :'likes_flavor', :'hates_flavor' => :'hates_flavor', :'berries' => :'berries', :'pokeathlon_stat_changes' => :'pokeathlon_stat_changes', :'move_battle_style_preferences' => :'move_battle_style_preferences', :'names' => :'names' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 377 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 65 def self.openapi_types { :'id' => :'Integer', :'name' => :'String', :'decreased_stat' => :'StatSummary', :'increased_stat' => :'StatSummary', :'likes_flavor' => :'BerryFlavorSummary', :'hates_flavor' => :'BerryFlavorSummary', :'berries' => :'Array<BerrySummary>', :'pokeathlon_stat_changes' => :'Array<NatureDetailPokeathlonStatChangesInner>', :'move_battle_style_preferences' => :'Array<NatureBattleStylePreference>', :'names' => :'Array<NatureName>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
347 348 349 350 351 352 353 354 355 356 357 358 359 360 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 347 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && name == o.name && decreased_stat == o.decreased_stat && increased_stat == o.increased_stat && likes_flavor == o.likes_flavor && hates_flavor == o.hates_flavor && berries == o.berries && pokeathlon_stat_changes == o.pokeathlon_stat_changes && move_battle_style_preferences == o.move_battle_style_preferences && names == o.names end |
#eql?(o) ⇒ Boolean
364 365 366 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 364 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
370 371 372 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 370 def hash [id, name, decreased_stat, increased_stat, likes_flavor, hates_flavor, berries, pokeathlon_stat_changes, move_battle_style_preferences, names].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 100 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 100.') end if @decreased_stat.nil? invalid_properties.push('invalid value for "decreased_stat", decreased_stat cannot be nil.') end if @increased_stat.nil? invalid_properties.push('invalid value for "increased_stat", increased_stat cannot be nil.') end if @likes_flavor.nil? invalid_properties.push('invalid value for "likes_flavor", likes_flavor cannot be nil.') end if @hates_flavor.nil? invalid_properties.push('invalid value for "hates_flavor", hates_flavor cannot be nil.') end if @berries.nil? invalid_properties.push('invalid value for "berries", berries cannot be nil.') end if @pokeathlon_stat_changes.nil? invalid_properties.push('invalid value for "pokeathlon_stat_changes", pokeathlon_stat_changes cannot be nil.') end if @move_battle_style_preferences.nil? invalid_properties.push('invalid value for "move_battle_style_preferences", move_battle_style_preferences cannot be nil.') end if @names.nil? invalid_properties.push('invalid value for "names", names cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 399 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/pokeapi_client/models/nature_detail.rb', line 225 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @name.nil? return false if @name.to_s.length > 100 return false if @decreased_stat.nil? return false if @increased_stat.nil? return false if @likes_flavor.nil? return false if @hates_flavor.nil? return false if @berries.nil? return false if @pokeathlon_stat_changes.nil? return false if @move_battle_style_preferences.nil? return false if @names.nil? true end |